@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # -- stdlib --
+import json
 import logging
 
 # -- third party --
@@ -11,6 +12,7 @@ import requests
 # -- own --
 from .common import detect_env
 
+
 # -- code --
 log = logging.getLogger('openbayes_serving.event')
 
@@ -35,8 +37,10 @@ def emit_event(name, data):
         encoded = data
     elif isinstance(data, str):
         encoded = data.encode('utf-8')
+    elif isinstance(data, (int, float)):
+        encoded = str(data)
     else:
-        encoded = msgpack.packb(data)
+        encoded = json.dumps(data).encode('utf-8')
 
     if detect_env() != 'production':
         data = _strip_bytes(data)
